Stan Math Library: stan/math/prim/mat/fun/sub_col.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

sub_col.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_SUB_COL_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_SUB_COL_HPP
3
4 #include <stan/math/prim/mat/fun/Eigen.hpp>
5 #include <stan/math/prim/mat/err/check_row_index.hpp>
6 #include <stan/math/prim/mat/err/check_column_index.hpp>
7
8 namespace stan {
9 namespace math {
10
19 template <typename T>
20 inline
21 Eigen::Matrix<T, Eigen::Dynamic, 1>
22 sub_col(const Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic>& m,
23 size_t i, size_t j, size_t nrows) {
24 stan::math::check_row_index("sub_col", "i", m, i);
25 if (nrows > 0)
26 stan::math::check_row_index("sub_col", "i+nrows-1", m, i+nrows-1);
27 stan::math::check_column_index("sub_col", "j", m, j);
28 return m.block(i - 1, j - 1, nrows, 1);
29 }
30
31
32 }
33 }
34
35 #endif
stan::math::sub_col
Eigen::Matrix< T, Eigen::Dynamic, 1 > sub_col(const Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &m, size_t i, size_t j, size_t nrows)
Return a nrows x 1 subcolumn starting at (i-1, j-1).
Definition: sub_col.hpp:22
stan
Definition: log_sum_exp.hpp:8
check_column_index.hpp
stan::math::check_row_index
bool check_row_index(const char *function, const char *name, const Eigen::Matrix< T_y, R, C > &y, size_t i)
Return true if the specified index is a valid row of the matrix.
Definition: check_row_index.hpp:32
check_row_index.hpp
Eigen.hpp
stan::math::check_column_index
bool check_column_index(const char *function, const char *name, const Eigen::Matrix< T_y, R, C > &y, const size_t i)
Return true if the specified index is a valid column of the matrix.
Definition: check_column_index.hpp:37

[ Stan Home Page ] © 2011–2016, Stan Development Team.